@@ -37,6 +37,8 @@ class OchronaReporter:
         :return: sys.exit -1 if vulns are discovered
         """
         reports = []
+        if len(sources) == 0:
+            sources.append("stdin")
         for index, (source, result) in enumerate(zip(sources, results)):
             if "confirmed_vulnerabilities" in result:
                 result["confirmed_vulnerabilities"] = list(
@@ -184,34 +186,32 @@ class BasicReport(BaseReport):
 
         if confirmed:
             print(f"{INFO}|{ERROR} ⚠️  Vulnerability Detected!{ENDC}")
-        else:
-            print(f"{INFO}|{WARNING} ⚠️  [Potential] Vulnerability Detected!{ENDC}")
-        print(ROW_BREAK)
-        print(f"{INFO}| Package -- {finding.get('name')}{ENDC}")
-        print(ROW_BREAK)
-        print(f"{INFO}| Installed Version -- {finding.get('found_version')}{ENDC}")
-        print(ROW_BREAK)
-        print(f"{INFO}| CVE -- {finding.get('cve_id')}{ENDC}")
-        print(ROW_BREAK)
-        print(f"{INFO}| Severity -- {finding.get('ochrona_severity_score')} {ENDC}")
-        print(ROW_BREAK)
-        affected_versions = ", ".join(
-            [
-                f"{f.get('operator')}{f.get('version_value')}"
-                for f in finding.get("affected_versions", [])
-            ]
-        )
-        print(
-            textwrap.fill(
-                f"{INFO}| Affected Versions -- \n| {affected_versions}{ENDC}",
-                (term_size.columns - 2),
-                replace_whitespace=False,
-                initial_indent="",
-                subsequent_indent="| ",
+            print(ROW_BREAK)
+            print(f"{INFO}| Package -- {finding.get('name')}{ENDC}")
+            print(ROW_BREAK)
+            print(f"{INFO}| Installed Version -- {finding.get('found_version')}{ENDC}")
+            print(ROW_BREAK)
+            print(f"{INFO}| CVE -- {finding.get('cve_id')}{ENDC}")
+            print(ROW_BREAK)
+            print(f"{INFO}| Severity -- {finding.get('ochrona_severity_score')} {ENDC}")
+            print(ROW_BREAK)
+            affected_versions = ", ".join(
+                [
+                    f"{f.get('operator')}{f.get('version_value')}"
+                    for f in finding.get("affected_versions", [])
+                ]
             )
-        )
-        print(ROW_BREAK)
-        print(LINE_BREAK)
+            print(
+                textwrap.fill(
+                    f"{INFO}| Affected Versions -- \n| {affected_versions}{ENDC}",
+                    (term_size.columns - 2),
+                    replace_whitespace=False,
+                    initial_indent="",
+                    subsequent_indent="| ",
+                )
+            )
+            print(ROW_BREAK)
+            print(LINE_BREAK)
 
 
 class FullReport(BaseReport):
@@ -237,62 +237,60 @@ class FullReport(BaseReport):
 
         if confirmed:
             print(f"{INFO}|{ERROR} ⚠️  Vulnerability Detected!{ENDC}")
-        else:
-            print(f"{INFO}|{WARNING} ⚠️  [Potential] Vulnerability Detected!{ENDC}")
-        print(ROW_BREAK)
-        print(f"{INFO}| Package -- {finding.get('name')}{ENDC}")
-        print(ROW_BREAK)
-        print(f"{INFO}| Installed Version -- {finding.get('found_version')}{ENDC}")
-        print(ROW_BREAK)
+            print(ROW_BREAK)
+            print(f"{INFO}| Package -- {finding.get('name')}{ENDC}")
+            print(ROW_BREAK)
+            print(f"{INFO}| Installed Version -- {finding.get('found_version')}{ENDC}")
+            print(ROW_BREAK)
 
-        print(
-            textwrap.fill(
-                f"{INFO}| Reason -- {finding.get('reason')}{ENDC}",
-                (term_size.columns - 2),
-                initial_indent="",
-                subsequent_indent="| ",
+            print(
+                textwrap.fill(
+                    f"{INFO}| Reason -- {finding.get('reason')}{ENDC}",
+                    (term_size.columns - 2),
+                    initial_indent="",
+                    subsequent_indent="| ",
+                )
             )
-        )
-        print(ROW_BREAK)
-        print(f"{INFO}| CVE -- {finding.get('cve_id')}{ENDC}")
-        print(ROW_BREAK)
-        print(
-            f"{INFO}| Vulnerability Publish Date -- {finding.get('publish_date')}{ENDC}"
-        )
-        print(ROW_BREAK)
-        print(f"{INFO}| Severity -- {finding.get('ochrona_severity_score')} {ENDC}")
-        print(ROW_BREAK)
-        print(
-            textwrap.fill(
-                f"{INFO}| Description -- {finding.get('description')}{ENDC}",
-                (term_size.columns - 2),
-                initial_indent="",
-                subsequent_indent="| ",
+            print(ROW_BREAK)
+            print(f"{INFO}| CVE -- {finding.get('cve_id')}{ENDC}")
+            print(ROW_BREAK)
+            print(
+                f"{INFO}| Vulnerability Publish Date -- {finding.get('publish_date')}{ENDC}"
             )
-        )
-        print(ROW_BREAK)
-        print(f"{INFO}| License -- {finding.get('license')} {ENDC}")
-        print(ROW_BREAK)
-        affected_versions = ", ".join(
-            [
-                f"{f.get('operator')}{f.get('version_value')}"
-                for f in finding.get("affected_versions", [])
-            ]
-        )
-        print(
-            textwrap.fill(
-                f"{INFO}| Affected Version(s) -- \n| {affected_versions}{ENDC}",
-                (term_size.columns - 2),
-                replace_whitespace=False,
-                initial_indent="",
-                subsequent_indent="| ",
+            print(ROW_BREAK)
+            print(f"{INFO}| Severity -- {finding.get('ochrona_severity_score')} {ENDC}")
+            print(ROW_BREAK)
+            print(
+                textwrap.fill(
+                    f"{INFO}| Description -- {finding.get('description')}{ENDC}",
+                    (term_size.columns - 2),
+                    initial_indent="",
+                    subsequent_indent="| ",
+                )
             )
-        )
-        print(ROW_BREAK)
-        references = "".join([f"\n| - {ref}" for ref in finding["references"]])
-        print(f"{INFO}| References -- {references}{ENDC}")
-        print(LINE_BREAK)
-        print(LINE_BREAK)
+            print(ROW_BREAK)
+            print(f"{INFO}| License -- {finding.get('license')} {ENDC}")
+            print(ROW_BREAK)
+            affected_versions = ", ".join(
+                [
+                    f"{f.get('operator')}{f.get('version_value')}"
+                    for f in finding.get("affected_versions", [])
+                ]
+            )
+            print(
+                textwrap.fill(
+                    f"{INFO}| Affected Version(s) -- \n| {affected_versions}{ENDC}",
+                    (term_size.columns - 2),
+                    replace_whitespace=False,
+                    initial_indent="",
+                    subsequent_indent="| ",
+                )
+            )
+            print(ROW_BREAK)
+            references = "".join([f"\n| - {ref}" for ref in finding["references"]])
+            print(f"{INFO}| References -- {references}{ENDC}")
+            print(LINE_BREAK)
+            print(LINE_BREAK)
 
 
 class JSONReport(BaseReport):
